@@ -352,10 +352,10 @@ merge.Matrix<-function(x,y,by.x,by.y,all.x=TRUE,all.y=TRUE,out.class=class(x),
   if(is.null(dim(x)))
     return(grr::matches(by.x,by.y,all.x,all.y,indexes=FALSE))
   indices<-grr::matches(by.x,by.y,all.x,all.y,nomatch = NULL)
-  x<-rBind(x,fill.x)
+  x<-rbind(x,fill.x)
   x<-as(grr::extract(x,indices$x),out.class)
   
-  y<-rBind(y,fill.y)
+  y<-rbind(y,fill.y)
   if(!is.null(colnames(x)) & !is.null(colnames(y)))
     colnames(y)[colnames(y) %in% colnames(x)]<-paste('y',colnames(y)[colnames(y) %in% colnames(x)],sep='.')
 
